# 	Copyright (c) 2005-2008 Peter V. Saveliev
#
# 	This file is part of Connexion project.
#
# 	Connexion is free software; you can redistribute it and/or modify
# 	it under the terms of the GNU General Public License as published by
# 	the Free Software Foundation; either version 3 of the License, or
# 	(at your option) any later version.
#
# 	Connexion is distributed in the hope that it will be useful,
# 	but WITHOUT ANY WARRANTY; without even the implied warranty of
# 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# 	GNU General Public License for more details.
#
# 	You should have received a copy of the GNU General Public License
# 	along with Connexion; if not, write to the Free Software
# 	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from cxutil import flags
from command import command, swrapper
from posix import environ

class backup (command):
	'''
	Backup operations
	'''

	mask = flags.Begin | flags.Bypass

	modules = [
		"write",
		"restore",
		"resurrect",
	]

	class lenv (command):
		'''
		Base class
		'''
		
		def getEnv(self):
			return (environ["CX_SOCKET"],environ["CX_CONFIG"])

	class write (lenv):
		'''
		Write configuration to disk
		'''

		def postUp(self,opts):
			result = swrapper()
			result.add_command(
				"system",
				"connexion-cli -bs %s -e tree > %s" % self.getEnv()
			)
			return result

	class restore (lenv):
		'''
		Merge configuration from disk
		'''

		def postUp(self,opts):
			result = swrapper()
			result.add_command(
				"system",
				"connexion-cli -abs %s -e 'merge;.source %s;commit'" % self.getEnv()
			)
			return result

	class resurrect (lenv):
		'''
		Merge configuration from disk, but do not execute
		'''

		def postUp(self,opts):
			result = swrapper()
			result.add_command(
				"system",
				"connexion-cli -abs %s -e 'merge;.source %s;commit noexec'" % self.getEnv()
			)
			return result
